@@ -1,8 +1,8 @@
 package App::CLI::Command;
 use strict;
 use warnings;
-use Pod::Simple::Text;
 use Locale::Maketext::Simple;
+use Carp ();
 
 =head1 NAME
 
@@ -107,6 +107,7 @@ sub usage {
     my ($self, $want_detail) = @_;
     my $fname = $self->filename;
     my($cmd) = $fname =~ m{\W(\w+)\.pm$};
+    require Pod::Simple::Text;
     my $parser = Pod::Simple::Text->new;
     my $buf;
     $parser->output_string(\$buf);
@@ -180,7 +181,7 @@ Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2005 by Chia-liang Kao E<lt>clkao@clkao.orgE<gt>.
+Copyright 2005-2006 by Chia-liang Kao E<lt>clkao@clkao.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
